==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/opa/OpaSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.opa;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Predicate;

public interface OpaSpecFluent<A extends OpaSpecFluent<A>> extends Fluent<A>{


    public String getCheckMethod();
    public A withCheckMethod(String checkMethod);
    public Boolean hasCheckMethod();
    public Boolean isFailClose();
    public A withFailClose(Boolean failClose);
    public Boolean hasFailClose();
    public A withNewFailClose(String arg1);
    public A withNewFailClose(boolean arg1);
    public A addToPolicy(int index,String item);
    public A setToPolicy(int index,String item);
    public A addToPolicy(String... items);
    public A addAllToPolicy(Collection<String> items);
    public A removeFromPolicy(String... items);
    public A removeAllFromPolicy(Collection<String> items);
    public List<String> getPolicy();
    public String getPolicy(int index);
    public String getFirstPolicy();
    public String getLastPolicy();
    public String getMatchingPolicy(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withPolicy(List<String> policy);
    public A withPolicy(String... policy);
    public Boolean hasPolicy();



}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/opa/OpaSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.opa;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Predicate;

public interface OpaSpecFluent<A extends OpaSpecFluent<A>> extends Fluent<A>{


    public String getCheckMethod();
    public A withCheckMethod(String checkMethod);
    public Boolean hasCheckMethod();
    public A withNewCheckMethod(String arg1);
    public A withNewCheckMethod(StringBuilder arg1);
    public A withNewCheckMethod(StringBuffer arg1);
    public Boolean isFailClose();
    public A withFailClose(Boolean failClose);
    public Boolean hasFailClose();
    public A withNewFailClose(String arg1);
    public A withNewFailClose(boolean arg1);
    public A addToPolicy(int index,String item);
    public A setToPolicy(int index,String item);
    public A addToPolicy(String... items);
    public A addAllToPolicy(Collection<String> items);
    public A removeFromPolicy(String... items);
    public A removeAllFromPolicy(Collection<String> items);
    public List<String> getPolicy();
    public String getPolicy(int index);
    public String getFirstPolicy();
    public String getLastPolicy();
    public String getMatchingPolicy(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingPolicy(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withPolicy(List<String> policy);
    public A withPolicy(String... policy);
    public Boolean hasPolicy();
    public A addNewPolicy(String arg1);
    public A addNewPolicy(StringBuilder arg1);
    public A addNewPolicy(StringBuffer arg1);



}
